@@ -1,15 +1,17 @@
 from abc import ABC, abstractmethod
-from typing import Optional
+from typing import List, Optional
 
 
 class Typer(ABC):
     @staticmethod
     def best_option(name: Optional[str] = None) -> "Typer":
+        from .cliclick import CliclickTyper
         from .noop import NoopTyper
         from .wtype import WTypeTyper
         from .xdotool import XDoToolTyper
+        from .ydotool import YdotoolTyper as YDoToolTyper
 
-        available_typers = [XDoToolTyper, WTypeTyper, NoopTyper]
+        available_typers = [XDoToolTyper, WTypeTyper, YDoToolTyper, CliclickTyper, NoopTyper]
 
         if name is not None:
             return next(typer for typer in available_typers if typer.name() == name)()
@@ -37,3 +39,7 @@ class Typer(ABC):
     @abstractmethod
     def insert_from_clipboard(self, active_window: str) -> None:
         pass
+
+    @abstractmethod
+    def type_numerical(self, codepoints: List[int], active_window: str) -> None:
+        pass
